@@ -1,15 +1,17 @@
 """Core testing functionality."""
 
 import asyncio
-from typing import Any, AsyncGenerator, List
+from collections.abc import AsyncGenerator
+from typing import Any
 
 import pytest
+
 from pypck.connection import PchkConnectionManager
 from pypck.lcn_addr import LcnAddr
 from pypck.module import ModuleConnection
 from pypck.pck_commands import PckGenerator
 
-from .fake_pchk import PchkServer
+from .mock_pchk import MockPchkServer
 
 HOST = "127.0.0.1"
 PORT = 4114
@@ -22,7 +24,7 @@ class MockPchkConnectionManager(PchkConnectionManager):
 
     def __init__(self, *args: Any, **kwargs: Any):
         """Construct mock for PchkConnectionManager."""
-        self.data_received: List[str] = []
+        self.data_received: list[str] = []
         super().__init__(*args, **kwargs)
 
     async def process_message(self, message: str) -> None:
@@ -54,9 +56,11 @@ def encode_pck(pck: str) -> bytes:
 
 
 @pytest.fixture
-async def pchk_server() -> AsyncGenerator[PchkServer, None]:
+async def pchk_server() -> AsyncGenerator[MockPchkServer, None]:
     """Create a fake PchkServer and run."""
-    pchk_server = PchkServer(host=HOST, port=PORT, username=USERNAME, password=PASSWORD)
+    pchk_server = MockPchkServer(
+        host=HOST, port=PORT, username=USERNAME, password=PASSWORD
+    )
     await pchk_server.run()
     yield pchk_server
     await pchk_server.stop()
@@ -89,9 +93,9 @@ async def module10(
 
 
 @pytest.fixture
-async def pchk_server_2() -> AsyncGenerator[PchkServer, None]:
+async def pchk_server_2() -> AsyncGenerator[MockPchkServer, None]:
     """Create a fake PchkServer and run."""
-    pchk_server = PchkServer(
+    pchk_server = MockPchkServer(
         host=HOST, port=PORT + 1, username=USERNAME, password=PASSWORD
     )
     await pchk_server.run()
