@@ -1,5 +1,7 @@
 """Tests for command generation directed at bus modules and groups."""
 
+from typing import Any
+
 import pytest
 
 from pypck.lcn_addr import LcnAddr
@@ -24,7 +26,7 @@ from pypck.pck_commands import PckGenerator
 
 NEW_VAR_SW_AGE = 0x170206
 
-COMMANDS = {
+COMMANDS: dict[str | bytes, Any] = {
     # Host commands
     **{
         f"^ping{counter:d}": (PckGenerator.ping, counter)
@@ -93,7 +95,7 @@ COMMANDS = {
             var,
             NEW_VAR_SW_AGE,
         )
-        for var in Var.variables  # type: ignore
+        for var in Var.variables()
     },
     **{
         f"MWS{Var.to_set_point_id(var) + 1:03d}": (
@@ -101,7 +103,7 @@ COMMANDS = {
             var,
             NEW_VAR_SW_AGE,
         )
-        for var in Var.set_points  # type: ignore
+        for var in Var.set_points()
     },
     **{
         f"MWC{Var.to_s0_id(var) + 1:03d}": (
@@ -109,7 +111,7 @@ COMMANDS = {
             var,
             NEW_VAR_SW_AGE,
         )
-        for var in Var.s0s  # type: ignore
+        for var in Var.s0s()
     },
     **{
         f"SE{Var.to_thrs_register_id(var) + 1:03d}": (
@@ -117,7 +119,7 @@ COMMANDS = {
             var,
             NEW_VAR_SW_AGE,
         )
-        for reg in Var.thresholds  # type: ignore
+        for reg in Var.thresholds()
         for var in reg
     },
     # Variable status (legacy commands)
@@ -128,7 +130,7 @@ COMMANDS = {
     "MWSB": (PckGenerator.request_var_status, Var.R2VARSETPOINT, NEW_VAR_SW_AGE - 1),
     **{
         "SL1": (PckGenerator.request_var_status, var, NEW_VAR_SW_AGE - 1)
-        for var in Var.thresholds[0]  # type: ignore
+        for var in Var.thresholds()[0]
     },
     # Output manipulation
     **{
@@ -165,6 +167,10 @@ COMMANDS = {
         f"A{output + 1:d}TA123": (PckGenerator.toggle_output, output, 123)
         for output in range(4)
     },
+    **{
+        f"A{output + 1:d}MT123": (PckGenerator.toggle_output, output, 123, True)
+        for output in range(4)
+    },
     "AU123": (PckGenerator.toggle_all_outputs, 123),
     # Relay state manipulation
     "R80-1U1-U0": (
@@ -301,7 +307,7 @@ COMMANDS = {
     # Variable manipulation
     **{
         f"X2{var.value | 0x40:03d}016225": (PckGenerator.update_status_var, var, 4321)
-        for var in Var.variables  # type: ignore
+        for var in Var.variables()
     },
     "X2030044129": (PckGenerator.var_abs, Var.R1VARSETPOINT, 4201),
     "X2030108129": (PckGenerator.var_abs, Var.R2VARSETPOINT, 4201),
@@ -310,7 +316,7 @@ COMMANDS = {
     "ZS30000": (PckGenerator.var_reset, Var.TVAR, 0x170205),
     **{
         f"Z-{var.value + 1:03d}4090": (PckGenerator.var_reset, var, 0x170206)
-        for var in Var.variables  # type: ignore
+        for var in Var.variables()
     },
     "ZA23423": (PckGenerator.var_rel, Var.TVAR, RelVarRef.CURRENT, 23423, 0x170205),
     "ZS23423": (PckGenerator.var_rel, Var.TVAR, RelVarRef.CURRENT, -23423, 0x170205),
@@ -322,7 +328,7 @@ COMMANDS = {
             -3000,
             0x170206,
         )
-        for var in Var.variables  # type: ignore
+        for var in Var.variables()
         if var != Var.TVAR
     },
     **{
@@ -333,7 +339,7 @@ COMMANDS = {
             -500,
             sw_age,
         )
-        for nvar, var in enumerate(Var.set_points)  # type: ignore
+        for nvar, var in enumerate(Var.set_points())
         for nref, ref in enumerate(RelVarRef)
         for sw_age in (0x170206, 0x170205)
     },
@@ -345,14 +351,14 @@ COMMANDS = {
             500,
             sw_age,
         )
-        for nvar, var in enumerate(Var.set_points)  # type: ignore
+        for nvar, var in enumerate(Var.set_points())
         for nref, ref in enumerate(RelVarRef)
         for sw_age in (0x170206, 0x170205)
     },
     **{
         f"SS{('R', 'E')[nref]}0500SR{r + 1}{i + 1}": (
             PckGenerator.var_rel,
-            Var.thresholds[r][i],  # type: ignore
+            Var.thresholds()[r][i],
             ref,
             -500,
             0x170206,
@@ -364,7 +370,7 @@ COMMANDS = {
     **{
         f"SS{('R', 'E')[nref]}0500AR{r + 1}{i + 1}": (
             PckGenerator.var_rel,
-            Var.thresholds[r][i],  # type: ignore
+            Var.thresholds()[r][i],
             ref,
             500,
             0x170206,
@@ -376,7 +382,7 @@ COMMANDS = {
     **{
         f"SS{('R', 'E')[nref]}0500S{1 << (4 - i):05b}": (
             PckGenerator.var_rel,
-            Var.thresholds[0][i],  # type: ignore
+            Var.thresholds()[0][i],
             ref,
             -500,
             0x170205,
@@ -387,7 +393,7 @@ COMMANDS = {
     **{
         f"SS{('R', 'E')[nref]}0500A{1 << (4 - i):05b}": (
             PckGenerator.var_rel,
-            Var.thresholds[0][i],  # type: ignore
+            Var.thresholds()[0][i],
             ref,
             500,
             0x170205,
@@ -558,6 +564,8 @@ COMMANDS = {
 
 
 @pytest.mark.parametrize("expected, command", COMMANDS.items())
-def test_command_generation_single_mod_noack(expected, command):
+def test_command_generation_single_mod_noack(
+    expected: str, command: tuple[Any, ...]
+) -> None:
     """Test if InputMod parses message correctly."""
     assert expected == command[0](*command[1:])
